"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = require("fs");
const path_1 = __importDefault(require("path"));
const child_process_1 = __importDefault(require("child_process"));
const constants_1 = require("./constants");
const preprocessor_configuration_1 = require("./preprocessor-configuration");
async function addCucumberPreprocessorPlugin(on, config) {
    const preprocessor = await (0, preprocessor_configuration_1.resolve)();
    const messagesPath = path_1.default.join(config.projectRoot, preprocessor.messages.output);
    const jsonPath = path_1.default.join(config.projectRoot, preprocessor.json.output);
    on("before:run", async () => {
        if (preprocessor.messages.enabled) {
            await fs_1.promises.rm(messagesPath, { force: true });
        }
    });
    on("after:run", async () => {
        if (preprocessor.json.enabled) {
            const messages = await fs_1.promises.open(messagesPath, "r");
            try {
                const json = await fs_1.promises.open(jsonPath, "w");
                try {
                    const child = child_process_1.default.spawn(preprocessor.json.formatter, {
                        stdio: [messages.fd, json.fd, "inherit"],
                    });
                    await new Promise((resolve, reject) => {
                        child.on("exit", (code) => {
                            if (code === 0) {
                                resolve();
                            }
                            else {
                                reject(new Error(`${preprocessor.json.formatter} exited non-successfully`));
                            }
                        });
                    });
                }
                finally {
                    await json.close();
                }
            }
            finally {
                await messages.close();
            }
        }
    });
    let currentTestStepStartedId;
    on("after:screenshot", async (details) => {
        let buffer;
        try {
            buffer = await fs_1.promises.readFile(details.path);
        }
        catch (_a) {
            return details;
        }
        const message = {
            attachment: {
                testStepId: currentTestStepStartedId,
                body: buffer.toString("base64"),
                mediaType: "image/png",
                contentEncoding: "BASE64",
            },
        };
        await fs_1.promises.writeFile(messagesPath, JSON.stringify(message) + "\n", {
            flag: "a",
        });
        return details;
    });
    on("task", {
        [constants_1.TASK_APPEND_MESSAGES]: async (messages) => {
            await fs_1.promises.writeFile(messagesPath, messages.map((message) => JSON.stringify(message)).join("\n") + "\n", {
                flag: "a",
            });
            return true;
        },
        [constants_1.TASK_TEST_STEP_STARTED]: (testStepStartedId) => {
            currentTestStepStartedId = testStepStartedId;
            return true;
        },
    });
}
exports.default = addCucumberPreprocessorPlugin;
